/*
 * Copyright (c) 2008, 2009 Nokia Corporation
 * Contact: integration@maemo.org
 *
 * Authors: Marcos Morais <morais@dee.ufcg.edu.br>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 * USA.
 */

#ifndef NM_SETTINGS_H
#define NM_SETTINGS_H

#include <glib.h>
#include <glib-object.h>

#include "nm_usb_setup.h"
#include "nm_bt_setup.h"
#include "nm_wlan_setup.h"

G_BEGIN_DECLS

#define  NM_SETTINGS_ENABLE         "ENABLED"
#define  NM_SETTINGS_IP             "IP"
#define  NM_SETTINGS_GATEWAY        "GATEWAY"
#define  NM_SETTINGS_MASK           "MASK"
#define  NM_SETTINGS_HOST           "HOST"
#define  NM_SETTINGS_MAC            "MAC"

#define NM_SETTINGS_FILE            ".netman"

#define NM_USB_SETTINGS_GROUP       "USB"
#define NM_BT_SETTINGS_GROUP        "BLUETOOTH"
#define NM_WLAN_SETTINGS_GROUP      "WLAN"

#define  NM_WLAN_SETTINGS_ESSID     "ESSID"
#define  NM_WLAN_SETTINGS_NAME      "NAME"



#define NM_SETTINGS_TYPE            (nm_settings_get_type ())
#define NM_SETTINGS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), NM_SETTINGS_TYPE, NmSettings))
#define NM_SETTINGS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), NM_SETTINGS_TYPE, NmSettingsClass))
#define IS_NM_SETTINGS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NM_SETTINGS_TYPE))
#define IS_NM_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), NM_SETTINGS_TYPE))
#define NM_SETTINGS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), NM_SETTINGS_TYPE, NmSettingsClass))

typedef struct _NmSettings      NmSettings;
typedef struct _NmSettingsClass NmSettingsClass;

struct _NmSettingsClass
{
    GObjectClass parent_class;
};

struct _NmSettings
{
    GObject parent;
};

GType        nm_settings_get_type (void);
NmSettings*  nm_settings_new      (void);

void     nm_settings_set_value (NmSettings *, const gchar *group, const gchar *key, const gchar *value);
gchar*   nm_settings_get_value (NmSettings *, const gchar *group, const gchar *key);
void     nm_settings_set_boolean (NmSettings *, const gchar *group, const gchar *key, gboolean value);
gboolean nm_settings_get_boolean (NmSettings *, const gchar *group, const gchar *key);
void     nm_settings_save (NmSettings *);
gboolean nm_settings_start (NmSettings *self);
void     nm_settings_set_defaults (NmSettings *self);

/* Get the singleton instance pointer */
NmSettings* nm_settings_get_context(void);

G_END_DECLS

#endif

